@@ -28,7 +28,6 @@
 #include "pulldialog.h"
 
 #include <KLocalizedString>
-#include <KUrl>
 #include <KRun>
 #include <KShell>
 #include <KPluginFactory>
@@ -115,10 +114,10 @@ FileViewGitPlugin::FileViewGitPlugin(QObject* parent, const QList<QVariant>& arg
     m_logAction->setText(xi18nd("@action:inmenu", "<application>Git</application> Log..."));
     connect(m_logAction, &QAction::triggered, this, &FileViewGitPlugin::log);
 
-    connect(&m_process, SIGNAL(finished(int, QProcess::ExitStatus)),
-            this, SLOT(slotOperationCompleted(int, QProcess::ExitStatus)));
-    connect(&m_process, SIGNAL(error(QProcess::ProcessError)),
-            this, SLOT(slotOperationError()));
+    connect(&m_process, QOverload<int, QProcess::ExitStatus>::of(&QProcess::finished),
+            this, &FileViewGitPlugin::slotOperationCompleted);
+    connect(&m_process, &QProcess::errorOccurred,
+            this, &FileViewGitPlugin::slotOperationError);
 }
 
 FileViewGitPlugin::~FileViewGitPlugin()
@@ -179,8 +178,8 @@ bool FileViewGitPlugin::beginRetrieval(const QString& directory)
         while (readUntilZeroChar(&process, buffer, sizeof(buffer)) > 0 ) {
             QString line = QTextCodec::codecForLocale()->toUnicode(buffer);
             // ----- recognize file status -----
-            char X = line[0].toAscii();  // X and Y from the table in `man git-status`
-            char Y = line[1].toAscii();
+            char X = line[0].toLatin1();  // X and Y from the table in `man git-status`
+            char Y = line[1].toLatin1();
             const QString fileName= line.mid(3);
             ItemVersion state = NormalVersion;
             switch (X) {
