@@ -20,29 +20,42 @@
 #include "pushdialog.h"
 #include "gitwrapper.h"
 
-#include <kcombobox.h>
-#include <klocale.h>
+#include <KConfigGroup>
+#include <KLocalizedString>
 
 #include <QCheckBox>
+#include <QComboBox>
 #include <QGroupBox>
 #include <QHBoxLayout>
 #include <QLabel>
 #include <QVBoxLayout>
+#include <QDialogButtonBox>
+#include <QPushButton>
 
 PushDialog::PushDialog (QWidget* parent ):
-    KDialog (parent, Qt::Dialog)
+    QDialog (parent, Qt::Dialog)
 {
-    this->setCaption(xi18nc("@title:window", "<application>Git</application> Push"));
-    this->setButtons(KDialog::Ok | KDialog::Cancel);
-    this->setDefaultButton(KDialog::Ok);
-    this->setButtonText(KDialog::Ok, i18nc("@action:button", "Push"));
+    this->setWindowTitle(xi18nc("@title:window", "<application>Git</application> Push"));
+    m_buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok|QDialogButtonBox::Cancel);
+    QWidget *mainWidget = new QWidget(this);
+    QVBoxLayout *mainLayout = new QVBoxLayout;
+    this->setLayout(mainLayout);
+    mainLayout->addWidget(mainWidget);
+    QPushButton *okButton = m_buttonBox->button(QDialogButtonBox::Ok);
+    okButton->setDefault(true);
+    okButton->setShortcut(Qt::CTRL | Qt::Key_Return);
+    this->connect(m_buttonBox, SIGNAL(accepted()), this, SLOT(accept()));
+    this->connect(m_buttonBox, SIGNAL(rejected()), this, SLOT(reject()));
+    m_buttonBox->button(QDialogButtonBox::Ok)->setDefault(true);
+    okButton->setText(i18nc("@action:button", "Push"));
 
     QWidget * boxWidget = new QWidget(this);
     QVBoxLayout * boxLayout = new QVBoxLayout(boxWidget);
-    this->setMainWidget(boxWidget);
+    mainLayout->addWidget(boxWidget);
 
     //Destination
     QGroupBox * destinationGroupBox = new QGroupBox(boxWidget);
+    mainLayout->addWidget(destinationGroupBox);
     boxLayout->addWidget(destinationGroupBox);
     destinationGroupBox->setTitle(i18nc("@title:group The remote host", "Destination"));
     QHBoxLayout * destinationHBox = new QHBoxLayout(destinationGroupBox);
@@ -50,12 +63,13 @@ PushDialog::PushDialog (QWidget* parent ):
 
     QLabel * remoteLabel = new QLabel(i18nc("@label:listbox a git remote", "Remote:"), destinationGroupBox);
     destinationHBox->addWidget(remoteLabel);
-    m_remoteComboBox = new KComboBox(false, destinationGroupBox);
+    m_remoteComboBox = new QComboBox(destinationGroupBox);
     destinationHBox->addWidget(m_remoteComboBox);
     destinationHBox->addStretch();
 
     //Branches
     QGroupBox* branchesGroupBox = new QGroupBox(boxWidget);
+    mainLayout->addWidget(branchesGroupBox);
     boxLayout->addWidget(branchesGroupBox);
     branchesGroupBox->setTitle(i18nc("@title:group", "Branches"));
     QHBoxLayout * branchesHBox = new QHBoxLayout(branchesGroupBox);
@@ -63,17 +77,18 @@ PushDialog::PushDialog (QWidget* parent ):
 
     QLabel * localBranchLabel = new QLabel(i18nc("@label:listbox", "Local Branch:"), branchesGroupBox);
     branchesHBox->addWidget(localBranchLabel);
-    m_localBranchComboBox = new KComboBox(false, branchesGroupBox);
+    m_localBranchComboBox = new QComboBox(branchesGroupBox);
     branchesHBox->addWidget(m_localBranchComboBox);
 
     branchesHBox->addStretch();
 
     QLabel * remoteBranchLabel = new QLabel(i18nc("@label:listbox", "Remote Branch:"), branchesGroupBox);
     branchesHBox->addWidget(remoteBranchLabel);
-    m_remoteBranchComboBox = new KComboBox(false, branchesGroupBox);
+    m_remoteBranchComboBox = new QComboBox(branchesGroupBox);
     branchesHBox->addWidget(m_remoteBranchComboBox);
 
     QGroupBox* optionsGroupBox = new QGroupBox(boxWidget);
+    mainLayout->addWidget(optionsGroupBox);
     boxLayout->addWidget(optionsGroupBox);
     optionsGroupBox->setTitle(i18nc("@title:group", "Options"));
     QHBoxLayout * optionsHBox = new QHBoxLayout(optionsGroupBox);
@@ -82,6 +97,8 @@ PushDialog::PushDialog (QWidget* parent ):
     m_forceCheckBox->setToolTip(i18nc("@info:tooltip", "Proceed even if the remote branch is not an ancestor of the local branch."));
     optionsHBox->addWidget(m_forceCheckBox);
 
+    mainLayout->addWidget(m_buttonBox);
+
     //populate UI
     GitWrapper * gitWrapper = GitWrapper::instance();
 
@@ -146,7 +163,7 @@ void PushDialog::localBranchSelectionChanged(const QString& newLocalBranch)
     if (index != -1) {
         m_remoteBranchComboBox->setCurrentIndex(index);
     }
-    this->enableButtonOk(m_remoteBranchComboBox->count() > 0);
+    QPushButton *okButton = m_buttonBox->button(QDialogButtonBox::Ok);
+    okButton->setEnabled(m_remoteBranchComboBox->count() > 0);
 }
 
-#include "pushdialog.moc"
